[{"locale":"es"},{"key":"lb","names":["lb","lb."],"mappings":{"default":{"default":"libra"}}},{"key":"LT","names":["LT","L.T."],"mappings":{"default":{"default":"libras imperiales"}}},{"key":"oz","names":["oz","oz."],"mappings":{"default":{"default":"onza"}}},{"key":"µg","names":["µg","mcg"],"mappings":{"default":{"default":"microgramo"}}},{"key":"gr","names":["g","gr"],"mappings":{"default":{"default":"gramo"}}},{"key":"kg","names":["kg"],"mappings":{"default":{"default":"kilogramo"}}},{"key":"mg","names":["mg"],"mappings":{"default":{"default":"miligramo"}}},{"key":"t","names":["t","T"],"mappings":{"default":{"default":"tonelada"}}}]
